@@ -23,7 +23,7 @@ use PDF::Create::Outline;
 use PDF::Image::GIF;
 use PDF::Image::JPEG;
 
-our $VERSION = '1.11';
+our $VERSION = '1.13';
 my $DEBUG = 0;
 
 
@@ -35,6 +35,38 @@ sub new
 	my $this   = shift;
 	my %params = @_;
 
+        # validate constructor keys
+        my %valid_constructor_keys = ('fh'       => 1,
+                                      'filename' => 1,
+                                      'Version'  => 1,
+                                      'PageMode' => 1,
+                                      'Author'   => 1,
+                                      'Creator'  => 1,
+                                      'Title'    => 1,
+                                      'Subject'  => 1,
+                                      'Keywords' => 1,
+                                      'Debug'    => 1);
+        foreach (keys %params) {
+            croak "Invalid constructor key '$_' received." 
+                unless (exists $valid_constructor_keys{$_});
+        }
+
+	if (exists $params{PageMode} && defined $params{PageMode}) {
+	    # validate PageMode key value
+            my %valid_page_mode_values = ('UseNone'     => 1,
+                                          'UseOutlines' => 1,
+                                          'UseThumbs'   => 1,
+                                          'FullScreen'  => 1);
+            croak "Invalid value for key 'PageMode' received '". $params{PageMode} . "'" 
+                unless (exists $valid_page_mode_values{$params{PageMode}});
+        }
+
+        if (exists $params{Debug} && defined $params{Debug}) {
+            # validate Debug key value
+            croak "Invalid value for key 'Debug' received '". $params{Debug} . "'"
+               unless ($params{Debug} =~ /^[1|0]$/);
+        }
+
 	my $class = ref($this) || $this;
 	my $self = {};
 	bless $self, $class;
@@ -544,7 +576,7 @@ sub new_outline
 sub get_page_size
 {
 	my $self = shift;
-	my $name = lc(shift);
+	my $name = shift;
 
 	my %pagesizes = ( 'A0'         => [ 0, 0, 2380, 3368 ],
 					  'A1'         => [ 0, 0, 1684, 2380 ],
@@ -562,12 +594,16 @@ sub get_page_size
 					  'EXECUTIVE'  => [ 0, 0, 522,  756 ],
 					  '36X36'      => [ 0, 0, 2592, 2592 ],
 					);
+        if (defined $name) {
+            $name = uc($name);
+            # validate page size
+            croak "Invalid page size name '$name' received." unless (exists $pagesizes{$name});
+        }
+        else {
+            $name = 'A4';
+        }
 
-	if ( !$pagesizes{ uc($name) } ) {
-		$name = "A4";
-	}
-
-	$pagesizes{ uc($name) };
+	return $pagesizes{$name};
 }
 
 sub new_page
@@ -1232,15 +1268,27 @@ If the document was converted into a PDF document
   from another form, this is the name of the application that
   created the document.
 
-- 'Title' the title of the document
+=item 'Title' 
 
-- 'Subject' the subject of the document
+the title of the document
 
-- 'Keywords' keywords associated with the document
+=item 'Subject' 
 
-- 'CreationDate' the date the document was created. This is passed
-  as an anonymous array in the same format as localtime returns.
-  (ie. a struct tm).
+the subject of the document
+
+=item 'Keywords' 
+
+keywords associated with the document
+
+=item 'CreationDate' 
+
+the date the document was created. This is passed
+as an anonymous array in the same format as localtime returns.
+(ie. a struct tm).
+
+=item 'Debug'
+
+the debug switch, defaults to 0. The other possible value is 1.
 
 =back
 
@@ -1360,8 +1408,8 @@ is rotated.
 =item * get_page_size(<pagesize>)
 
 Returns the size of standard paper sizes to use for MediaBox-parameter
-of C<new_page>. C<get_page_size> has one required parameter to 
-specify the paper name. Possible values are a0-a6, letter, broadsheet,
+of C<new_page>. C<get_page_size> has one optional parameter to 
+specify the paper name. Possible values are a0-a6, a4l, letter, broadsheet,
 ledger, tabloid, legal, executive and 36x36. Default is a4.
 
   my $root = $pdf->new_page( 'MediaBox' => $pdf->get_page_size('A4') );
